@@ -5,11 +5,12 @@
 import os
 import user
 
+from cola import core
 from cola import serializer
 from cola.models import observable
 
 # Here we store settings
-_rcfile = os.path.join(user.home, '.cola')
+_rcfile = os.path.join(core.decode(user.home), '.cola')
 
 
 class SettingsModel(observable.ObservableModel):
@@ -40,7 +41,10 @@ class SettingsManager(object):
         """Returns the SettingsModel singleton"""
         if not SettingsManager._settings:
             if os.path.exists(_rcfile):
-                SettingsManager._settings = serializer.load(_rcfile)
+                try:
+                    SettingsManager._settings = serializer.load(_rcfile)
+                except: # bad json
+                    SettingsManager._settings = SettingsModel()
             else:
                 SettingsManager._settings = SettingsModel()
         return SettingsManager._settings
