@@ -4,6 +4,7 @@ from PyQt4.QtCore import Qt
 
 import cola
 from cola import settings
+from cola import gitcfg
 from cola import qtutils
 from cola import qtcompat
 from cola import qt
@@ -24,6 +25,13 @@ class MainWindow(MainWindowBase):
         # Dockwidget options
         qtcompat.set_common_dock_options(self)
 
+        self.classic_dockable = gitcfg.instance().get('cola.classicdockable')
+
+        if self.classic_dockable:
+            self.classicdockwidget = self.create_dock('Cola Classic')
+            self.classicwidget = classic.widget(parent=self)
+            self.classicdockwidget.setWidget(self.classicwidget)
+
         # "Actions" widget
         self.actiondockwidget = self.create_dock('Actions')
         self.actiondockwidgetcontents = qt.QFlowLayoutWidget(parent=self)
@@ -37,11 +45,7 @@ class MainWindow(MainWindowBase):
         self.stash_button = qt.create_button('Stash...', layout)
         self.alt_button = qt.create_button('Exit Diff Mode', layout)
         self.alt_button.hide()
-
-        self.action_spacer = QtGui.QSpacerItem(1, 1,
-                                               QtGui.QSizePolicy.MinimumExpanding,
-                                               QtGui.QSizePolicy.MinimumExpanding)
-        self.actiondockwidgetcontents.layout().addItem(self.action_spacer)
+        layout.addStretch()
         self.actiondockwidget.setWidget(self.actiondockwidgetcontents)
 
         # "Repository Status" widget
@@ -53,10 +57,12 @@ class MainWindow(MainWindowBase):
         self.commitdockwidgetcontents = QtGui.QWidget()
 
         self.commitdockwidgetlayout = QtGui.QVBoxLayout(self.commitdockwidgetcontents)
-        self.commitdockwidgetlayout.setMargin(4)
+        self.commitdockwidgetlayout.setMargin(0)
+        self.commitdockwidgetlayout.setSpacing(0)
 
         self.vboxlayout = QtGui.QVBoxLayout()
-        self.vboxlayout.setSpacing(0)
+        self.vboxlayout.setSpacing(2)
+        self.vboxlayout.setMargin(0)
 
         self.commitmsg = QtGui.QTextEdit(self.commitdockwidgetcontents)
         self.commitmsg.setMinimumSize(QtCore.QSize(1, 1))
@@ -65,11 +71,10 @@ class MainWindow(MainWindowBase):
         self.commitmsg.setSizePolicy(policy)
         self.commitmsg.setLineWrapMode(QtGui.QTextEdit.NoWrap)
         self.commitmsg.setAcceptRichText(False)
-        self.vboxlayout.addWidget(self.commitmsg)
 
         self.hboxlayout = QtGui.QHBoxLayout()
-        self.hboxlayout.setSpacing(3)
-        self.hboxlayout.setContentsMargins(2, 6, 2, 0)
+        self.hboxlayout.setSpacing(0)
+        self.hboxlayout.setMargin(0)
 
         # Sign off and commit buttons
         self.signoff_button = qt.create_button('Sign Off')
@@ -79,10 +84,6 @@ class MainWindow(MainWindowBase):
         self.position_label = QtGui.QLabel(self.actiondockwidgetcontents)
         self.position_label.setAlignment(Qt.AlignLeft)
 
-        # Spacer between position and amend
-        self.spacer = QtGui.QSpacerItem(1, 1,
-                                        QtGui.QSizePolicy.MinimumExpanding,
-                                        QtGui.QSizePolicy.Minimum)
         # Amend checkbox
         self.amend_checkbox = QtGui.QCheckBox(self.commitdockwidgetcontents)
         self.amend_checkbox.setText(tr('Amend Last Commit'))
@@ -90,10 +91,12 @@ class MainWindow(MainWindowBase):
         self.hboxlayout.addWidget(self.signoff_button)
         self.hboxlayout.addWidget(self.commit_button)
         self.hboxlayout.addWidget(self.position_label)
-        self.hboxlayout.addItem(self.spacer)
+        self.hboxlayout.addStretch()
         self.hboxlayout.addWidget(self.amend_checkbox)
 
+        self.vboxlayout.addWidget(self.commitmsg)
         self.vboxlayout.addLayout(self.hboxlayout)
+
         self.commitdockwidgetlayout.addLayout(self.vboxlayout)
         self.commitdockwidget.setWidget(self.commitdockwidgetcontents)
 
@@ -106,7 +109,7 @@ class MainWindow(MainWindowBase):
         self.diffdockwidget = self.create_dock('Diff Viewer')
         self.diffdockwidgetcontents = QtGui.QWidget()
         self.diffdockwidgetlayout = QtGui.QVBoxLayout(self.diffdockwidgetcontents)
-        self.diffdockwidgetlayout.setMargin(3)
+        self.diffdockwidgetlayout.setMargin(0)
 
         self.display_text = QtGui.QTextEdit(self.diffdockwidgetcontents)
         self.display_text.setMinimumSize(QtCore.QSize(1, 1))
@@ -134,7 +137,7 @@ class MainWindow(MainWindowBase):
         self.menu_copy = self.create_action('Copy', local=True)
         self.menu_paste = self.create_action('Paste')
         self.menu_select_all = self.create_action('Select All')
-        self.menu_options = self.create_action('Options')
+        self.menu_options = self.create_action('Preferences')
         self.menu_delete = self.create_action('Delete')
         self.menu_undo = self.create_action('Undo')
         self.menu_redo = self.create_action('Redo')
@@ -318,6 +321,8 @@ class MainWindow(MainWindowBase):
         self.tools_menu.addAction(self.menu_classic)
         self.tools_menu.addAction(self.menu_dag)
         self.tools_menu.addSeparator()
+        if self.classic_dockable:
+            self.tools_menu.addAction(self.classicdockwidget.toggleViewAction())
         self.tools_menu.addAction(self.diffdockwidget.toggleViewAction())
         self.tools_menu.addAction(self.actiondockwidget.toggleViewAction())
         self.tools_menu.addAction(self.commitdockwidget.toggleViewAction())
@@ -361,9 +366,13 @@ class MainWindow(MainWindowBase):
         bottom = Qt.BottomDockWidgetArea
 
         self.addDockWidget(top, self.commitdockwidget)
+        if self.classic_dockable:
+            self.addDockWidget(top, self.classicdockwidget)
         self.addDockWidget(top, self.statusdockwidget)
         self.addDockWidget(top, self.actiondockwidget)
         self.addDockWidget(bottom, self.logdockwidget)
+        if self.classic_dockable:
+            self.tabifyDockWidget(self.classicdockwidget, self.commitdockwidget)
         self.tabifyDockWidget(self.logdockwidget, self.diffdockwidget)
 
     def create_dock(self, title):
